#
# spec file for package python-django-bootstrap4
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-bootstrap4
Version:        24.1
Release:        1.2
Summary:        Bootstrap support for Django projects
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/zostera/django-bootstrap4
Source:         https://github.com/zostera/django-bootstrap4/archive/v%{version}.tar.gz#/django-bootstrap4-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
Requires:       python-beautifulsoup4
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  gdal-devel
# /SECTION
%python_subpackages

%description
Bootstrap support for Django projects.

%prep
%autosetup -p1 -n django-bootstrap4-%{version}

# Remove need to install gis, as the tests do not exercise this yet
sed -i '/django.contrib.gis/d' tests/app/settings.py
sed -Ei '/(gisform|polygon)/d' tests/forms.py

# gh#zostera/django-bootstrap4#662
# Upstream uses setuptools_scm that adds everything in the git
# repository so we need to do the same here manually to do not depend
# on git.
cat << EOF > MANIFEST.in
recursive-include src/bootstrap4/templates/bootstrap4 *.html
EOF

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python manage.py test -v2 --noinput

%files %{python_files}
%doc AUTHORS README.md
%license LICENSE
%{python_sitelib}/bootstrap4
%{python_sitelib}/django_bootstrap4-%{version}*-info

%changelog
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 24.1:
  * Fix CheckboxSelectMultiple on Django>4 (#672, @heso).
* Mon Jan 22 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add %%{?sle15_python_module_pythons} to build for modern python in
  SLE/Leap
- Delete not needed patch skip-failing-tests.patch
- Update to 23.4:
  - Use setuptools-scm to build package (#664).
  23.3:
  - Use ruff instead of black for formatting (#653).
  - Add support for Python 3.12 (#658).
  - Add support for Django 5.0 (#658).
  - Revert packaging tools to setuptools, build, tox and twine (#658).
  23.2:
  - Fix references to example application (#648).
  - Remove support for Python 3.7 (EOL) (#646).
  - Switch to Hatch (#638).
  - Fix readthedocs (#603).
  - Remove version restriction on importlib-metadata (#604).
  - Replace m2r2 with sphinx-mdinclude (#605).
  23.1:
  - Add support for Django 4.2 (#601).
  - Update requirements and packages (#601).
  - Stop using coveralls (#601).
  22.3:
  - Add support for Python 3.11 (#554).
  22.2:
  - Update Bootstrap to 4.6.2 (#499).
  - Drop support for Django 2.2 (EOL) (#500).
  - Add support for Django 4.1 (#500).
  22.1:
  - Add support for Django 4 (#447).
  - Fix urls in example (#418, #444).
* Thu Feb 24 2022 Matej Cepl <mcepl@suse.com>
- Update to 21.2:
  - Switch to a CalVer YY.MINOR versioning scheme. MINOR is
    the number of the release in the given year. This is the
    first release in 2021 using this scheme, so its version is
    21.1. The next version this year will be 21.2. The first
    version in 2022 will be 22.1.
  - Add support for Django 4.0 and Python 3.10 (#349).
  - Fix faulty example code
  - No line break in FileInput in horizontal layout.
  - Actually use the bundles JavaScript.
  - Drop support for Django 3.0, extended support stopped on
    2021-04-01.
  - Add support for Django 3.2.
  - Use bundled Bootstrap JavaScript, no need for separate popper.js.
  - Updated default Bootstrap to 4.6.0.
  - Add Dependabot for updates to dependencies.
  - Rename AUTHORS.md to AUTHORS, remove authors section from
    documentation.
  - Revert to setuptools for packaging.
  - Add docs and tests to sdist.
  - Fix example by not installing editable version.
- Add skip-failing-tests.patch skipping failing tests
  (gh#zostera/django-bootstrap4#439).
* Mon Jan 25 2021 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v2.3.1
* Fri May  8 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.1.1
